@@ -2,7 +2,60 @@ import pandas as pd
 import streamlit as st
 from migration.connector.destination.base import Destination
 from migration.connector.source import Source
-from migration.util import validation_util, validation_table_util
+from migration.util import validation_util, validation_table_util, validation_partition_table_util
+
+def count_partition_table_validation(source: Source, destination: Destination, source_table: str,
+                                     destination_table: str, is_source_filter: bool,
+                                     is_dest_filter: bool, source_filter_columns: list,
+                                     source_filter_values: list, dest_filter_columns: list, dest_filter_values: list):
+    try:
+        result_dict = validation_partition_table_util.count_validation(source_table, destination_table,
+                                                             source,
+                                                             destination, is_source_filter, is_dest_filter,source_filter_columns, source_filter_values,dest_filter_columns, dest_filter_values)
+        source_dict = {}
+        destination_dict = {}
+        source_keys = []
+        destination_keys = []
+        for key in result_dict:
+            if 'source' in key:
+                if '_source_' in key:
+                    final_key = key.replace('_source_', '_')
+                elif 'source_' in key:
+                    final_key = key.replace('source_', '')
+                source_dict[final_key] = [result_dict[key]]
+                source_keys.append(key)
+            elif 'destination' in key:
+                if '_destination_' in key:
+                    final_key = key.replace('_destination_', '_')
+                elif 'destination_' in key:
+                    final_key = key.replace('destination_', '')
+                destination_dict[final_key] = [result_dict[key]]
+                destination_keys.append(key)
+        d_value = int(result_dict['source_count']) - int(result_dict['destination_count'])
+        percentage = d_value / int(result_dict['source_count'])
+        source_dict['difference'] = [d_value]
+        source_dict['percentage'] = [percentage]
+        destination_dict['difference'] = 0
+        destination_dict['percentage'] = 0
+
+        source_df = pd.DataFrame.from_dict(source_dict, orient='index')
+        destination_df = pd.DataFrame.from_dict(destination_dict, orient='index')
+        return source_df, destination_df
+    except Exception as e:
+        raise e
+
+def count_table_validation_without_df(source: Source, destination: Destination, source_table: str, destination_table: str):
+    try:
+        result_dict = validation_table_util.count_validation(source_table, destination_table,
+                                                             source,
+                                                             destination)
+        source_count = result_dict['source_count']
+        destination_count = result_dict['destination_count']
+        abs_value = abs(int(source_count) - int(destination_count))
+        return source_count,destination_count,abs_value
+    except Exception as e:
+        raise e
+
 
 def count_table_validation(source: Source, destination: Destination, source_table: str, destination_table: str):
     try:
@@ -223,6 +276,16 @@ def line_by_line_validation_table(source: Source, destination: Destination, sour
     except Exception as e:
         raise e
 
+def line_by_line_without_ddl_validation(source: Source, destination: Destination, source_query: str, destination_query: str):
+    try:
+        result = validation_util.line_by_line_without_ddl_validation(source_query, destination_query, source, destination)
+        source_result = result['source_result']
+        destination_result = result['destination_result']
+
+        return source_result, destination_result
+    except Exception as e:
+        raise e
+
 
 def data_diff_table_validation(source: Source, destination: Destination, source_table: str, destination_table: str):
     try:
@@ -231,6 +294,44 @@ def data_diff_table_validation(source: Source, destination: Destination, source_
     except Exception as e:
         raise e
 
+def schema_table_validation(source: Source, destination: Destination, source_table: str, destination_table: str):
+    try:
+        diff_result = validation_table_util.schema_validation(source_table, destination_table, source, destination)
+        return diff_result
+    except Exception as e:
+        raise e
+
+def pk_id_table_validation(source: Source, destination: Destination, source_table: str, destination_table: str, pk_id: str):
+    try:
+        diff_result = validation_table_util.pk_id_column_validation(source_table, destination_table, source, destination, pk_id)
+        return diff_result
+    except Exception as e:
+        raise e
+
+def pk_id_partition_table_validation(source: Source, destination: Destination,
+                                     source_table: str, destination_table: str, pk_id: str,
+                                     is_source_filter: bool,
+                                     is_dest_filter: bool, source_filter_columns: list,
+                                     source_filter_values: list, dest_filter_columns: list, dest_filter_values: list):
+    try:
+        diff_result = validation_partition_table_util.pk_id_column_validation(source_table, destination_table, source, destination, pk_id, is_source_filter, is_dest_filter,source_filter_columns, source_filter_values,dest_filter_columns, dest_filter_values)
+        return diff_result
+    except Exception as e:
+        raise e
+
+def pk_id_validation(source: Source, destination: Destination, source_query: str, destination_query: str, pk_id: str):
+    try:
+        diff_result = validation_util.pk_id_validation(source_query, destination_query, source, destination, pk_id)
+        return diff_result
+    except Exception as e:
+        raise e
+
+def pk_id_table_validation_with_count(source: Source, destination: Destination, source_query: str, destination_query: str, pk_id: str, expected_count: int):
+    try:
+        diff_result = validation_table_util.pk_id_column_validation_with_count(source_query, destination_query, source, destination, pk_id, expected_count)
+        return diff_result
+    except Exception as e:
+        raise e
 
 def display_validation_result(source_df_result, destination_df_result):
     try:
